@@ -1,41 +1,39 @@
-#! /usr/local/bin/perl 
-
-eval '(exit $?0)' && eval 'exec /usr/local/bin/perl $0 ${1+"$@"}'
-&& eval 'exec /usr/local/bin/perl $0 $argv:q'
-if 0;
+#! /bin/env perl 
 
 # ============================================================================
 
-# $Id: snmpgetnext.pl,v 2.4 2005/07/20 13:53:07 dtown Rel $
+# $Id: snmpgetnext.pl,v 6.0 2009/09/09 15:05:32 dtown Rel $
 
-# Copyright (c) 2000-2005 David M. Town <dtown@cpan.org>
+# Copyright (c) 2000-2009 David M. Town <dtown@cpan.org>
 # All rights reserved.
 
 # This program is free software; you may redistribute it and/or modify it
-# under the same terms as Perl itself.
+# under the same terms as the Perl 5 programming language system itself.
 
 # ============================================================================
 
-use Net::SNMP v5.1.0 qw(snmp_type_ntop DEBUG_ALL);
+use strict;
+use warnings;
+
+use Net::SNMP 6.0 qw( snmp_type_ntop DEBUG_ALL );
 use Getopt::Std;
 
-use strict;
-use vars qw($SCRIPT $VERSION %OPTS);
+our $SCRIPT  = 'snmpgetnext';
+our $VERSION = 'v6.0.0';
 
-$SCRIPT  = 'snmpgetnext';
-$VERSION = '2.3.0';
+our %OPTS;
 
-# Validate the command line options
+# Validate the command line options.
 if (!getopts('a:A:c:dD:E:m:n:p:r:t:u:v:x:X:', \%OPTS)) {
-   _usage();
+   usage();
 }
 
 # Do we have enough information?
 if (@ARGV < 2) {
-   _usage();
+   usage();
 }
 
-# Create the SNMP session
+# Create the SNMP session.
 my ($s, $e) = Net::SNMP->session(
    -hostname  => shift,
    exists($OPTS{a}) ? (-authprotocol =>  $OPTS{a}) : (),
@@ -50,51 +48,51 @@ my ($s, $e) = Net::SNMP->session(
    exists($OPTS{u}) ? (-username     =>  $OPTS{u}) : (),
    exists($OPTS{v}) ? (-version      =>  $OPTS{v}) : (),
    exists($OPTS{x}) ? (-privprotocol =>  $OPTS{x}) : (),
-   exists($OPTS{X}) ? (-privpassword =>  $OPTS{X}) : ()
+   exists($OPTS{X}) ? (-privpassword =>  $OPTS{X}) : (),
 );
 
 # Was the session created?
-if (!defined($s)) {
-   _exit($e);
+if (!defined $s) {
+   abort($e);
 }
 
 my @args = (
    exists($OPTS{E}) ? (-contextengineid => $OPTS{E}) : (),
    exists($OPTS{n}) ? (-contextname     => $OPTS{n}) : (),
-   -varbindlist    => \@ARGV
+   -varbindlist    => \@ARGV,
 );
 
-# Send the SNMP message
-if (!defined($s->get_next_request(@args))) {
-   _exit($s->error());
+# Send the SNMP message.
+if (!defined $s->get_next_request(@args)) {
+   abort($s->error());
 }
 
-# Print the results
-foreach ($s->var_bind_names()) {
-   printf(
-      "%s = %s: %s\n", $_,
-      snmp_type_ntop($s->var_bind_types()->{$_}),
-      $s->var_bind_list()->{$_},
-   );
+# Print the results.
+for ($s->var_bind_names()) {
+   printf "%s = %s: %s\n",
+          $_,
+          snmp_type_ntop($s->var_bind_types()->{$_}),
+          $s->var_bind_list()->{$_};
 }
 
-# Close the session
+# Close the session.
 $s->close();
- 
+
 exit 0;
 
-# [private] ------------------------------------------------------------------
+# [functions] ----------------------------------------------------------------
 
-sub _exit
+sub abort
 {
-   printf join('', sprintf("%s: ", $SCRIPT), shift(@_), ".\n"), @_;
+   printf "$SCRIPT: " . ((@_ > 1) ? shift(@_) : '%s') . ".\n", @_;
    exit 1;
 }
 
-sub _usage
+sub usage
 {
    print << "USAGE";
-$SCRIPT v$VERSION
+$SCRIPT $VERSION
+Copyright (c) 2000-2009 David M. Town.  All rights reserved.
 Usage: $SCRIPT [options] <hostname> <oid> [...]
 Options: -v 1|2c|3      SNMP version
          -d             Enable debugging
